1.0.0 API documentation: GLM_EXT_scalar_constants

| 1.0.0 API documentation

Functions
GLM_EXT_scalar_constants
Stable extensions

## Functions
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | cos_one_over_two ()
| Return the value of cos(1 / 2) for floating point types.
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | epsilon ()
| Return the epsilon constant for floating point types.
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | pi ()
| Return the pi constant for floating point types.

## Detailed Description

Provides a list of constants and precomputed useful values.

Include <glm/ext/scalar_constants.hpp> to use the features of this extension.